package com.ruoyi.web.modules.architecture.mapper;

import java.util.List;
import com.ruoyi.web.modules.architecture.domain.BizDrugIncompatibilityStandard;

/**
 * 药物禁配标准主表 Mapper
 */
public interface BizDrugIncompatibilityStandardMapper
{
    BizDrugIncompatibilityStandard selectBizDrugIncompatibilityStandardById(Long id);

    List<BizDrugIncompatibilityStandard> selectBizDrugIncompatibilityStandardList(BizDrugIncompatibilityStandard query);

    int insertBizDrugIncompatibilityStandard(BizDrugIncompatibilityStandard row);

    int updateBizDrugIncompatibilityStandard(BizDrugIncompatibilityStandard row);

    int deleteBizDrugIncompatibilityStandardByIds(Long[] ids);
}
